@@ -6,18 +6,19 @@ class BillingStatementEntity:
         self.billing_details_collection = data.get('billing_details_collection')
         self.billing_statement_merchant_name = data.get('billing_statement_merchant_name')
         self.billing_statement_number = data.get('billing_statement_number')
+        self.billing_statement_url = data.get('billing_statement_url')
         self.customer_reference_id = data.get('customer_reference_id')
         self.client_secret = data.get('client_secret')
         self.status = data.get('status')
         self.currency = data.get('currency')
         self.line_items = data.get('line_items')
         self.livemode = data.get('livemode')
-        self.url = data.get('url')
         self.payment_intent = data.get('payment_intent')
         self.metadata = data.get('metadata')
         self.success_url = data.get('success_url')
         self.cancel_url = data.get('cancel_url')
         self.payment_methods = data.get('payment_methods')
+        self.setup_future_usage = data.get('setup_future_usage')
         self.statement_descriptor = data.get('statement_descriptor')
         self.description = data.get('description')
         self.submit_type = data.get('submit_type')
